@@ -46,45 +46,39 @@ class FocusedWave(AcousticField):
     def _apply_delay(self, dx=None):
         """
         Apply a temporal delay to focus the wave at a given lateral position (x_focal) and fixed focal depth (Foc).
-    
         Returns:
             ndarray: Delayed signals, shape (nbPiezo, len(burst) + max_delay).
         """
         try:
-            # 1. Récupération des paramètres
-            if dx is None:
-                dx = self.params['dx']
+            # 1. Positions latérales de tous les éléments (en mètres)
+            Xmin, Xmax = self.params['Xrange'][0], self.params['Xrange'][1]
+            element_positions = np.linspace(Xmin, Xmax, self.params['num_elements'])
 
-            c0 = self.params['c0']  # Vitesse du son (m/s)
-            num_elements = self.params['num_elements']
-            element_width = self.params['element_width']  # Largeur d'un élément (mm)
-            Foc = self.params['Foc']  # Profondeur focale (mm)
-            x_focal = self.focal_line  # Position latérale focale (mm)
+            # 2. Trouver l'indice de l'élément le plus proche de self.focal_line
+            center_idx = np.argmin(np.abs(element_positions - self.focal_line))
 
-            # 2. Calcul de l'indice central (élément le plus proche de x_focal)
-            center_idx = int(round(x_focal / element_width))
+            # 3. Limites des indices pour N_piezoFocal éléments centrés sur self.focal_line
+            N_focal = self.params['N_piezoFocal']
+            start_idx = max(0, center_idx - N_focal // 2)
+            end_idx = min(self.params['num_elements'] - 1, start_idx + N_focal - 1)
 
-            # 3. Limites des indices pour N_piezo_Foc éléments centrés sur x_focal
-            start_idx = max(0, center_idx - self.params['N_piezoFoc']  // 2)
-            end_idx = min(num_elements - 1, start_idx + self.params['N_piezoFoc']  - 1)
-
-            # 4. Positions latérales des éléments sélectionnés (en mm)
+            # 4. Positions des éléments sélectionnés (en mètres)
             selected_indices = np.arange(start_idx, end_idx + 1)
-            element_positions = selected_indices * element_width
+            selected_positions = element_positions[selected_indices]
 
-            # 5. Distance entre chaque élément sélectionné et le point focal (x_focal, Foc)
-            distances = np.sqrt((x_focal - element_positions)**2 + Foc**2)
+            # 5. Distance entre chaque élément sélectionné et le point focal (self.focal_line, self.params['Foc'])
+            distances = np.sqrt((self.focal_line - selected_positions)**2 + self.params['Foc']**2)
 
-            # 6. Délais en secondes : (distance_max - distance) / c0
+            # 6. Délais en secondes : (distance_max - distance) / self.params['c0']
             max_distance = np.max(distances)
-            delays = (max_distance - distances) / c0  # Délais en secondes
+            delays = (max_distance - distances) / self.params['c0']
 
-            # 7. Conversion en échantillons
+            # 7. Conversion en échantillons (vérifier que self.kgrid.dt est en secondes)
             delay_samples = np.round(delays / self.kgrid.dt).astype(int)
             max_delay = np.max(delay_samples)
 
-            # 8. Application des délais (uniquement pour les éléments sélectionnés)
-            delayed_signals = np.zeros((num_elements, len(self.burst) + max_delay))
+            # 8. Application des délais
+            delayed_signals = np.zeros((self.params['num_elements'], len(self.burst) + max_delay))
             for i, idx in enumerate(selected_indices):
                 shift = delay_samples[i]
                 delayed_signals[idx, shift:shift + len(self.burst)] = self.burst
@@ -96,6 +90,8 @@ class FocusedWave(AcousticField):
             return None
 
 
+
+
         
     def plot_delay(self):
         """
